measuretools.scale_contents_of_measures_in_expr
===============================================

.. autofunction:: abjad.tools.measuretools.scale_contents_of_measures_in_expr.scale_contents_of_measures_in_expr
